@@ -1,5 +1,7 @@
 from pyzeebe.client.client import ZeebeClient
 from pyzeebe.common import exceptions
+from pyzeebe.credentials.camunda_cloud_credentials import CamundaCloudCredentials
+from pyzeebe.credentials.oauth_credentials import OAuthCredentials
 from pyzeebe.task.task import Task
 from pyzeebe.task.task_context import TaskContext
 from pyzeebe.task.task_status_controller import TaskStatusController
